@@ -259,12 +259,18 @@ class KoshExecutionGraph(object):
             seed = random.random()
         G.seed = seed
         if verbose:
-            import matplotlib.pyplot as plt
-            nx.draw(self._graph)
-            plt.show()
-            png_name = png_template + "_IN.png"
-            plt.savefig(png_name.format(seed))
-            plt.clf()
+            try:
+                if "DISPLAY" not in os.environ or os.environ["DISPLAY"] == "":
+                    import matplotlib
+                    matplotlib.use("agg", force=True)
+                import matplotlib.pyplot as plt
+                nx.draw(self._graph)
+                plt.show()
+                png_name = png_template + "_IN.png"
+                plt.savefig(png_name.format(seed))
+                plt.clf()
+            except ImportError:
+                raise RuntimeError("Could not import matplotlib, will not plot anything")
         used_nodes = collections.OrderedDict()
         for (n1, n2) in self._graph.edges():
             if n1 in used_nodes:
@@ -337,6 +343,7 @@ class KoshExecutionGraph(object):
             self.paths[format] = pths
         else:
             pths = self.paths[format]
+
         # Ok let's generate the new network with only the paths
         out = nx.OrderedDiGraph()
         out.seed = G.seed
@@ -368,7 +375,7 @@ class KoshExecutionGraph(object):
         cache_file_only = kargs.pop("cache_file_only", False)
         use_cache = kargs.pop("use_cache", False)
         cache_dir = kargs.pop("cache_dir", kosh_cache_dir)
-        starters, end = find_network_ends(graph, start=True, end=True)
+        _, end = find_network_ends(graph, start=True, end=True)
         previous = list(graph.predecessors(node))
         if len(previous) == 0:
             # Ok we are at the start e.g a loader
@@ -376,7 +383,7 @@ class KoshExecutionGraph(object):
             node[1].use_cache = use_cache
             node[1].cache_dir = cache_dir
             node[1]._user_passed_parameters = (None, kargs)
-            if getitem_key != slice(None, None, None):
+            if not isinstance(getitem_key, slice) or getitem_key != slice(None, None, None):
                 if "__getitem__" in node[1].__class__.__dict__:
                     out = node[1][getitem_key]
                 else:
@@ -411,10 +418,10 @@ class KoshExecutionGraph(object):
                 # we are done
                 return inputs[0]
             if hasattr(self, "operate_"):
-                out = self.operate_(*inputs, format=node[0])
+                out = self.operate_(*inputs, format=output_format)
                 return out
             elif hasattr(self, "transform_"):
-                out = self.transform_(*inputs, format=node[0])
+                out = self.transform_(*inputs, format=output_format)
                 return out
             elif isinstance(self, kosh.exec_graphs.core.KoshExecutionGraph):
                 return inputs
