@@ -1,13 +1,6 @@
 # Kosh transformer for scikit learn models
 from .core import KoshTransformer
 import numpy
-try:
-    import sklearn.cluster
-    import sklearn.preprocessing
-    import sklearn.model_selection
-    has_skl = True
-except ImportError:
-    has_skl = False
 
 
 class Splitter(KoshTransformer):
@@ -17,7 +10,7 @@ class Splitter(KoshTransformer):
     def __init__(self, train_size=None,
                  test_size=None,
                  validation_size=None,
-                 splitter=sklearn.model_selection.ShuffleSplit,
+                 splitter=None,
                  random_state=None,
                  n_splits=1,
                  *args, **kargs):
@@ -56,10 +49,9 @@ class Splitter(KoshTransformer):
         :rtype: Splitter
         """
 
-        if not has_skl:
-            raise RuntimeError(
-                "Could not import sklearn, Scikit Learn-based transformers are not available")
-
+        if splitter is None:
+            from sklearn.model_selection import ShuffleSplit
+            splitter = ShuffleSplit
         if train_size is None and test_size is None and validation_size is None:
             train_size = .9
             test_size = .1
@@ -135,11 +127,10 @@ class StandardScaler(KoshTransformer):
 
     def __init__(self, *args, **kargs):
         """SKL-based scaler transformer"""
-        if not has_skl:
-            raise RuntimeError(
-                "Could not import sklearn, Scikit Learn-based transformers are not available")
 
-        self.scaler = sklearn.preprocessing.StandardScaler(*args, **kargs)
+        from sklearn.preprocessing import StandardScaler
+
+        self.scaler = StandardScaler(*args, **kargs)
         super(StandardScaler, self).__init__(*args, **kargs)
 
     def transform(self, input, format):
@@ -186,10 +177,6 @@ class SKL(KoshTransformer):
                  labels, list of ndarray with samples in each class
                         possibly sub-sampled via n_sample/sampling_method
         """
-        if not has_skl:
-            raise RuntimeError(
-                "Could not import sklearn, Scikit Learn-based transformers are not available")
-
         kw = {}
         for arg in ["n_samples", "sampling_method", "random_state"]:
             setattr(self, arg, kargs.pop(arg, None))
@@ -249,12 +236,9 @@ class DBSCAN(SKL):
     types = {"numpy": ["estimator", "numpy"]}
 
     def __init__(self, *args, **kargs):
-        if not has_skl:
-            raise RuntimeError(
-                "Could not import sklearn, Scikit Learn-based transformers are not available")
-
-        kargs["skl_class"] = sklearn.cluster.DBSCAN
-        super(DBSCAN, self).__init__(**kargs)
+        from sklearn.cluster import DBSCAN
+        kargs["skl_class"] = DBSCAN
+        super().__init__(**kargs)
 
 
 class KMeans(SKL):
@@ -269,9 +253,6 @@ class KMeans(SKL):
     types = {"numpy": ["estimator", "numpy"]}
 
     def __init__(self, *args, **kargs):
-        if not has_skl:
-            raise RuntimeError(
-                "Could not import sklearn, Scikit Learn-based transformers are not available")
-
-        kargs["skl_class"] = sklearn.cluster.KMeans
+        from sklearn.cluster import KMeans
+        kargs["skl_class"] = KMeans
         super(KMeans, self).__init__(**kargs)
